/*
 * Copyright (c) 2011-2020, The Linux Foundation. All rights reserved.
 * Copyright (c) 2022 Qualcomm Innovation Center, Inc. All rights reserved.
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef WLAN_HDD_SYSFS_POLICY_MGR_H
#define WLAN_HDD_SYSFS_POLICY_MGR_H

 #ifdef WLAN_SYSFS

/**
 * hdd_sysfs_pm_cinfo_create(): Initialize pm_cinfo specific sysfs
 * @driver_kobject: Driver Kobject
 *
 * Function to initialize pm_cinfo specific mode syfs files.
 *
 * Return: NONE
 */
void hdd_sysfs_pm_cinfo_create(struct kobject *driver_kobject);

/**
 * hdd_sysfs_pm_cinfo_destroy(): Remove pm_cinfo sysfs file
 * @driver_kobject: Driver Kobject
 *
 * Function to remove pm_cinfo specific mode syfs files.
 *
 * Return: NONE
 */
void hdd_sysfs_pm_cinfo_destroy(struct kobject *driver_kobject);

/**
 * hdd_sysfs_pm_pcl_create() - API to create pm_pcl
 * @driver_kobject: sysfs driver kobject
 *
 * file path: /sys/kernel/wifi/pm_pcl
 *
 * usage:
 *      echo [arg_0] > pm_pcl
 *
 * Return: 0 on success and errno on failure
 */
int hdd_sysfs_pm_pcl_create(struct kobject *driver_kobject);

/**
 * hdd_sysfs_pm_pcl_destroy() -
 *   API to destroy pm_pcl
 *
 * Return: none
 */
void
hdd_sysfs_pm_pcl_destroy(struct kobject *driver_kobject);
#else
static inline int
hdd_sysfs_pm_pcl_create(struct kobject *driver_kobject)
{
	return 0;
}

static inline void
hdd_sysfs_pm_pcl_destroy(struct kobject *driver_kobject)
{
}

static inline
void hdd_sysfs_pm_cinfo_create(struct kobject *driver_kobject)
{
}

static inline
void hdd_sysfs_pm_cinfo_destroy(struct kobject *driver_kobject)
{
}
#endif
#endif
